@@ -20,6 +20,8 @@ from flask import current_app, url_for
 from flask.ext.flatpages import Page, pygmented_markdown
 from flask.ext.login import current_user
 
+from utils import truncate_markdown
+
 class Users(object) :
     """
         Users API class providing static methods to work with users
@@ -170,7 +172,7 @@ class Link(object) :
         """
         Render used by Jinja2 templates
         """
-        _template = '<a href="{}" class="{}" id="{}">{}</a>'
+        _template = u'<a href="{}" class="{}" id="{}">{}</a>'
         return _template.format(self.url, self.category, 
                                     self.uid, self.label)
 
@@ -239,12 +241,13 @@ class Content(Page) :
 
     @property
     def tags(self) :
-        return self.meta.get(u'tags')
+        return self.meta.get(u'tags', []).join(',')
 
 
     @tags.setter
     def tags(self, tags) :
-        self._setmeta(u'tags', tags)
+        val = [t.strip() for t in tags.split(',')]
+        self._setmeta(u'tags', val)
 
 
     @property
@@ -279,8 +282,9 @@ class Content(Page) :
     
     @property
     def summary(self) :
-        max_length = current_app.config.get(u'SUMMARY_LENGTH')
-        return self.html_renderer(self.body[:max_length] + '...')
+        max_length = current_app.config[u'SUMMARY_LENGTH']
+        markdown = truncate_markdown(self.body, max_length)
+        return self.html_renderer(markdown)
 
     
     @property
